// 订单相关
import { request } from "@/lib/service"
 
/**
 * @desc 提交订单前数据确认接口
 * buy_type * 购买类型：0默认加入购物车 1立即购买
 * cart_ids 选中的购物车IDs，多个则使用逗号分隔(buy_type=0时必填)
 * sku_ids SKUIDs，多个则使用逗号分隔(buy_type=1时必填)
 * cart_numbers 购买数量s，多个则使用逗号分隔(buy_type=1时必填)
 */
export function preConfirmOrderData(params) {
	return request({
		url: 'zsxcx/orderDetail.htm',
		method: 'post',
		data: params,
		needMask: true
	})
}

/**
 * @desc 提交订单
 * look up docs
 */
export function confirmOrder(params) {
	return request({
		url: 'zsxcx/orderInfoXcx.htm',
		method: 'post',
		data: params,
		needMask: true
	})
}

/**
 * @desc 获取订单列表
 */
export function orderList(params) {
	return request({
		url: 'zsxcx/orderXcx.htm',
		method: 'post',
		data: params,
		needMask: true
	})
}

/**
 * @desc 订单详情
 */
export function orderDetail(order_sn) {
	return request({
		url: 'zsxcx/snapshotXcx.htm',
		method: 'post',
		data: {
			order_sn
		},
		needMask: true
	})
}


/**
 * @desc 提醒发货接口
 */
export function remindOrder({order_id, order_sn}) {
	return request({
		url: 'zsxcx/remindXcx.htm',
		method: 'post',
		data: {
			order_sn,
			order_id
		},
		needMask: true
	})
}


/**
 * @desc 取消订单
 */
export function cancelOrder(order_sn) {
	return request({
		url: 'zsxcx/orderCancelXcx.htm',
		method: 'post',
		data: {
			order_sn
		},
		needMask: true
	})
}

 
/**
 * @desc 申请退款/退货退款/退货/取消订单等订单操作申请接口
 *  @param  order_sn
 * @param {type} apply_type 申请类型：1退款 2退货退款 3取消订单 4退货
 */
export function applyBack({order_sn, apply_type}) {
	return request({
		url: 'zsxcx/applyRrcXcx.htm',
		method: 'post',
		data: {
			order_sn,
			apply_type
		},
		needMask: true
	})
}

/**
 * @desc 确认收货
 */
export function recieveOrder(order_sn) {
	return request({
		url: 'zsxcx/orderConfirmXcx.htm',
		method: 'post',
		data: {
			order_sn
		}
	})
}

/**
 * @desc 撤销XXX
 * @param {type} order_sn 
 * @param {type} cancel_type 
 */
export function undoOrder({order_sn, cancel_type}) {
	return request({
		url: 'zsxcx/cancelRrcApplyXcx.htm',
		method: 'post',
		data: {
			order_sn,
			cancel_type
		},
		needMask: true
	})
}

/**
 * @desc 签收退款
 */
export function recieveOrderRefund(order_sn) {
	return request({
		url: 'zsxcx/confirmReceivedRefundXcx.htm',
		method: 'post',
		data: {
			order_sn
		},
		needMask: true
	})
}

/**
 * @desc 延长退款时间
 */
export function addRefundTime(order_sn) {
	return request({
		url: 'zsxcx/extendReceivedRefundXcx.htm',
		method: 'post',
		data: {
			order_sn
		},
		needMask: true
	})
}

/**
 * @desc 查询账户管理订单数量信息
 */
export function orderNum() {
	return request({
		url: 'zsxcx/getOrderCount.htm',
		method: 'post'
	})
}

/**
 * @desc 修改订单地址
 */
export function changeOrderAddr(params) {
	return request({
		url: 'zsxcx/editOrderAddress.htm',
		method: 'post',
		data: params,
		needMask: true
	})
}

/**
 * @desc 订单商品溯源
 * @param { Number | String } og_id 订单商品id
 */
export function safeOrigin(og_id) {
	return request({
		url: 'zsxcx/getWarehouseGoodsMsgZS.htm',
		method: 'post',
		data: {
			og_id
		},
		needMask: true
	})
}