import { cancelOrder, remindOrder, applyBack, undoOrder, recieveOrder, recieveOrderRefund, addRefundTime } from "@/apis/order.js"
import createOrder from '@/utils/modules/pay.js'
import { isFunction } from '@/utils/types.js'
import { cOrder_status } from '@/config/global.js'
const order_mixin = {
	filters: {
		cOrderStatus(key) {
			return cOrder_status[key].text || ''
		}
	},
	methods: {			
		
		// 取消订单
		async orderCancel(order_sn, cb) {
			try{
				const { status, data } = await cancelOrder(order_sn)
				if(status) {
					cb && isFunction(cb) && cb() 
					this.$toast({title: '订单取消成功'})
				}
			}catch(e){
				this.$toast({title: '取消失败'})
				//TODO handle the exception
			}
		},
		
		// 提醒发货
		async orderRemind(order_sn, order_id, cb) {
			try{
				const { status, data } = await remindOrder({order_sn, order_id})
				if(status) {
					cb && isFunction(cb) && cb() 
					this.$toast({title: '提醒成功'})
				}
			}catch(e){
				this.$toast({title: e.msg || '提醒失败'})
				//TODO handle the exception
			}
		},
		
		// 申请退款
		async applyBack(order_sn, type, cb) {
			try{
				const { status, data } = await applyBack({order_sn, apply_type: type})
				if(status) {
					cb && isFunction(cb) && cb() 
					this.$toast({title: '申请成功'})
				}
			}catch(e){
				console.log(e)
				this.$toast({title: '申请失败'})
				//TODO handle the exception
			}
		},
		
		// 支付
		async orderPay(order_sn, fn) {
			await createOrder({
				order_sn,
				successCb: () => {
					fn && isFunction(fn) && fn()
				}
			})
		},
		
		// 撤销
		async orderUndo(order_sn, type, cb) {
			try{
				const { status, data } = await undoOrder({order_sn, cancel_type: type})
				if(status) {
					cb && isFunction(cb) && cb() 
					this.$toast({title: '申请成功'})
				}
			}catch(e){
				console.log(e)
				this.$toast({title: e.msg || '申请失败'})
				//TODO handle the exception
			}
		},
		
		// 确认收货
		async orderRecieve(order_sn, cb) {
			try{
				const { status, data } = await recieveOrder(order_sn)
				if(status) {
					cb && isFunction(cb) && cb() 
					this.$toast({title: '收货成功'})
				}
			}catch(e){
				console.log(e)
				this.$toast({title: e.msg || '申请失败'})
				//TODO handle the exception
			}
		},
		
		// 签收退款
		async orderRefund(order_sn, cb) {
			try{
				const { status, data } = await recieveOrderRefund(order_sn)
				if(status) {
					cb && isFunction(cb) && cb() 
					this.$toast({title: '签收成功'})
				}
			}catch(e){
				this.$toast({title:e.msg ||  '签收失败'})
				//TODO handle the exception
			}
		},
		
		// 签收退款
		async orderAddRefund(order_sn, cb) {
			try{
				const { status, data } = await addRefundTime(order_sn)
				if(status) {
					cb && isFunction(cb) && cb() 
					this.$toast({title: '操作成功'})
				}
			}catch(e){
				this.$toast({title: e.msg || '操作失败'})
				//TODO handle the exception
			}
		}
	}
}

export default order_mixin