import { setStorage, setStorageAsync, removeStorage } from '@/lib/storage'
// import store from '@/store/index.js'
import { login, logout, getUserInfo } from '@/apis/user.js'
import { getStoreInfo } from '@/apis/common.js'
import Toast from '@/lib/toast/index.js'
import { login_wx } from '@/utils/modules/login.js'

const state = {
	token: null,
	openid: null,
	unionid: null,
	session_key: '',
	userInfo: {},// 昵称，头像，手机号码
	// location: {}, // 经纬度
	appid: '',
	
	storeInfo: {},
	isOverdue: false, // 服务是否过期
}

const mutations = {
	SETTOKEN(state, token){
		state.token = token
	},
	SETLOGINSTATUS(state, status) {
		state.isLogin = status
	},
	SETUSERINFO(state, userInfo){
		state.userInfo = userInfo
	},
	SETSTOREINFO(state, storeInfo) {
		state.storeInfo = storeInfo
	}, 
	LOGIN(state, token) {
		state.token = token
	},
	LOGOUT(state){
		state.token = ''
		state.userInfo = {}
	}
}

const actions = {
	setToken: ({commit}, token) => {
		commit('SETTOKEN', token)
		setStorageAsync('token',token)
	},
	setLoginStatus: ({commit}, status) => {
		commit('SETLOGINSTATUS', status)
	},
	// setLocation: async ({state}) => {
	// 	uni.getLocation({
	// 		type: 'gcj02',
	// 		success: res => {
	// 			state.location.longitude =  res.longitude || null
	// 			state.location.latitude = res.latitude || null
	// 		}
	// 	})
	// },
	setUserInfo: async ({commit}, userInfo) => {
		try{
			const { status, data } = await getUserInfo()
			if(status) {
				commit('SETUSERINFO', data)
			}
		}catch(e){
			Toast({title: e.msg || '登录失败'})
		}
		
	},
	login: async ({commit}, form) => {
		try{
			const { status, data } = await login(form)
			if(status) {
				await setStorage('token', data.token)
				// 这里返回了用户名，但后面会有个接口单独返回，所以这里不操作useInfo
				commit('LOGIN', data.token)
				Toast({
					title: '登录成功',
					cb: () => uni.navigateBack()
				})
			}
			
			
		}catch(e){
			console.log(e)
			login_wx()
			Toast({title: e.msg || '登录失败'})
		}
	},
	logout: async ({commit})=>{
		try{
			const { status, data } = await logout()
			if(status) {
				commit('LOGOUT')
				removeStorage('token')
				Toast({
					title: '退出成功',
					cb: () => uni.navigateBack()
				})
			}
		}catch(e){
			Toast({title: e.msg || '退出登录失败'})
		}
	},

	getStoreInfo: async ({commit}) => {
		try{
			const { status, data } = await getStoreInfo()
			if(status) {
				commit('SETSTOREINFO', data)
			}
		}catch(e){
			console.log(e)
			//TODO handle the exception
		}
	}
}

export default {
    namespaced: true, 
    state,
	mutations,
	actions
}