import { isFunction } from '@/utils/types.js'
import Toast from '@/lib/toast/index.js'
/**
 * 多页加载
 */
class LoadMore {
    constructor() {
        this.resetParams()
    }
	
	// params 和 页数页码合并组成参数
    async getList(params, cb) {
        try {
			if(!isFunction(cb)) return { status: false, data: null, msg: '参数类型不正确' }
			if(this.flat) return { status: false,  data: null, msg: '请求中，请勿重复操作' }
			// !!this.totalpage  用于判断是否是初始值0
			if(this.totalPage && (this.page > this.totalPage)) {
				Toast({title: '没有更多数据了'})
				return { status: false,  data: null, msg:  '没有更多页面了' }
			}
			const requestParams = Object.assign(params, {
				page: this.page,
				pagenum: this.pagenum
			})
			const { status, data } = await cb(requestParams)
			if(!status) return { status: false,  data: null, msg:  '请求失败' }
			const count = data.pageinfo.count // 总数
			const pages = data.pageinfo.pages // 总页数
			// const pages = Math.ceil(count / this.pagenum)
			this.page ++
			this.total = count 
			this.totalPage = pages
			this.flat = false
			// time是订单用的
			return { status: true, data: data.list, time: data.time || 0, msg:  '成功' }
        } catch (e) {
			console.log(e)
			return Toast({title: '获取列表失败'})
        }
    }
	
	// 重置页数 页码参数
	resetParams() {
		this.page = 1 // 当前页面
		this.pagenum = 10 // 每页的数量
		this.total = 0
		this.totalPage = 0 // 总页数
		this.flat = false // 是否在请求
	}
}

export default LoadMore